
// declare globals
var paddles;
var ball;
var leftScore = 0;
var rightScore = 0;

// called automatically when the program starts
function setup() {
  createCanvas(500, 300);

  // create paddles
  paddles = [
    {
      x: 0,
      y: height / 2,
      w: 20,
      h: 100,
      speed: 3,
      upKey: "W".charCodeAt(0), // note that the letter is capital
      downKey: "S".charCodeAt(0), // note that the letter is capital
    },
    {
      x: width,
      y: height / 2,
      w: 20,
      h: 100,
      speed: 3,
      upKey: UP_ARROW, // for a full list of special keycodes, see http://p5js.org/reference/#p5/keyCode
      downKey: DOWN_ARROW,
    },
  ];

  resetBall();
}

function resetBall() {
  // create ball
  ball = {};

  ball.x = width / 2;
  ball.y = height / 2;
  ball.radius = 5;

  var speed = 8;
  var direction = random(PI*2); // get random radians
  ball.velX = cos(direction) * speed;
  ball.velY = sin(direction) * speed;

}

// called repeatedly as long as the program is running
// update and draw logic goes here
function draw() {
  background(0, 0, 0); // clear the screen to 0/255 red, 0/255 green, 0/255 blue (black)
  strokeWeight(3); // set outline thickness
  stroke(255, 255, 255); // set outline color to 255/255 red, 255/255 green, 255/255 blue (white)

  // PADDLE STUFF //
  for (var i = 0; i < paddles.length; i++) {
    // move paddle up and down
    var p = paddles[i];
    if (keyIsDown(p.upKey)) {
      p.y = p.y - p.speed;
    }
    if (keyIsDown(p.downKey)) {
      p.y = p.y + p.speed;
    }

    // draw paddle
    fill(255, 255, 255);
    rect(p.x - p.w/2, p.y - p.h/2, p.w, p.h);
  }

  // BALL POSITION UPDATE //
  ball.x = ball.x + ball.velX;
  ball.y = ball.y + ball.velY;

  // BALL AND PADDLE INTERACTION // 
  for (var i = 0; i < paddles.length; i++) {
    var p = paddles[i];
    var r = ball.radius;
    if (   (ball.x + r >= p.x - p.w/2
         && ball.x - r <= p.x + p.w/2)
        && (ball.y + r >= p.y - p.h/2
         && ball.y - r <= p.y + p.h/2) ) {
      if (ball.x > width/2) {
        ball.velX = -abs(ball.velX);
      }
      else {
        ball.velX = abs(ball.velX);        
      }
    }
  }

  // BALL TOP/BOTTOM BOUNCES //
  if (ball.y < 0 + ball.radius) {
    ball.y = 0 + ball.radius;
    ball.velY = -ball.velY;
  }
  if (ball.y > height - ball.radius) {
    ball.y = height - ball.radius;
    ball.velY = -ball.velY;
  }

  // DRAW BALL //
  fill(255, 255, 255);
  rect(ball.x - ball.radius, ball.y - ball.radius, ball.radius*2, ball.radius*2);

  // SCORING //
  if (ball.x < 0) {
    rightScore = rightScore + 1
    resetBall();
  }
  if (ball.x > width) {
    leftScore = leftScore + 1
    resetBall();
  }
}